Package: jpstat
Type: Package
Title: Tools for Easy Use of 'e-Stat', 'RESAS' API, Etc
Version: 0.4.0
Authors@R: person("Mizuki", "Uchida", email = "uchidamizuki@vivaldi.net", role = c("aut", "cre"))
Description: Provides tools to use API such as 'e-Stat' (<https://www.e-stat.go.jp/>), 
    the portal site for Japanese government statistics, and 
    'RESAS' (Regional Economy and Society Analyzing System, <https://resas.go.jp>). 
License: MIT + file LICENSE
URL: https://github.com/UchidaMizuki/jpstat,
        https://uchidamizuki.github.io/jpstat/
BugReports: https://github.com/UchidaMizuki/jpstat/issues
Encoding: UTF-8
Suggests: keyring (>= 1.2.0), knitr, rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
RoxygenNote: 7.2.3
Imports: dplyr (>= 0.8.0), httr, pillar, purrr (>= 1.0.0), rlang (>=
        0.3.0), stringr (>= 1.3.0), tibble (>= 1.3.1), tidyr (>=
        1.0.0), vctrs, navigatr (>= 0.2.0), lifecycle, stickyr
Depends: R (>= 4.1.0)
NeedsCompilation: no
Packaged: 2023-07-15 14:48:18 UTC; UchidaMizuki
Author: Mizuki Uchida [aut, cre]
Maintainer: Mizuki Uchida <uchidamizuki@vivaldi.net>
Repository: CRAN
Date/Publication: 2023-07-15 21:20:05 UTC
Built: R 4.6.0; ; 2026-04-30 12:52:12 UTC; unix
