Package: jpstat
Type: Package
Title: Tools for Easy Use of the 'e-Stat' API
Version: 0.5.0
Authors@R: person("Mizuki", "Uchida", email = "uchidamizuki@vivaldi.net", role = c("aut", "cre"))
Description: Provides tools to use the 'e-Stat' API
    (<https://www.e-stat.go.jp/>), the portal site for Japanese
    government statistics.
License: MIT + file LICENSE
URL: https://github.com/UchidaMizuki/jpstat,
        https://uchidamizuki.github.io/jpstat/
BugReports: https://github.com/UchidaMizuki/jpstat/issues
Encoding: UTF-8
Suggests: keyring (>= 1.2.0), knitr, rmarkdown, testthat (>= 3.0.0)
Config/testthat/edition: 3
Imports: dplyr (>= 0.8.0), pillar, purrr (>= 1.0.0), rlang (>= 0.3.0),
        stringr (>= 1.3.0), tibble (>= 1.3.1), tidyr (>= 1.0.0), vctrs,
        navigatr (>= 0.2.0), lifecycle, stickyr (>= 0.1.3), httr2, cli
Depends: R (>= 4.1.0)
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-20 23:24:27 UTC; uchid
Author: Mizuki Uchida [aut, cre]
Maintainer: Mizuki Uchida <uchidamizuki@vivaldi.net>
Repository: CRAN
Date/Publication: 2026-07-20 23:40:02 UTC
