# Generated by roxygen2: do not edit by hand

S3method(collect,estat)
S3method(collect,tbl_estat)
S3method(obj_sum,tbl_estat)
S3method(summary,estat)
S3method(summary,tbl_estat)
export(activate)
export(deactivate)
export(estat)
export(estat_table_info)
export(itemise)
export(itemize)
export(rekey)
export(rekey_with)
export(resas)
import(rlang)
import(vctrs)
importFrom(dplyr,collect)
importFrom(navigatr,activate)
importFrom(navigatr,deactivate)
importFrom(navigatr,itemise)
importFrom(navigatr,itemize)
importFrom(navigatr,rekey)
importFrom(navigatr,rekey_with)
importFrom(pillar,obj_sum)
importFrom(pillar,type_sum)
