#' @importFrom navigatr activate
#' @export
navigatr::activate

#' @importFrom navigatr deactivate
#' @export
navigatr::deactivate

#' @importFrom navigatr rekey
#' @export
navigatr::rekey

#' @importFrom navigatr rekey_with
#' @export
navigatr::rekey_with

#' @importFrom navigatr itemise
#' @export
navigatr::itemise

#' @importFrom navigatr itemize
#' @export
navigatr::itemize
